@@ -338,9 +338,15 @@ class PodspecTool(object):
             if "/*\"" in content:
                 content = re.sub("/\*\"", "/*.h\"", content, 0, flags=re.I)
         content = re.sub("\t", "    ", content, 0, flags=re.I)
-        content = re.sub("s.preserve_paths *=( *((\'|\")(\D*?)(\'|\") *,? *\n))*", "", content, 1, flags=re.I)
-        content = re.sub("if spec\[:resource[s]?\]\n *ss.resources = spec\[:resource[s]?\]\n *end", "", content, 1,flags=re.I)
-        content = re.sub("if spec\[:resource_bundle[s]?\]\n *ss.resource_bundle[s]? = spec\[:resource_bundle[s]?\]\n *end", "",content, 1, flags=re.I)
+        if ".resource" in content:
+            new_content = re.sub("end\n* *$", "    s.resources = nil\nend", content, 1, flags=re.I)
+        if ".resource_bundle" in content:
+            new_content = re.sub("end\n* *$", "    s.resource_bundles = nil\nend", content, 1, flags=re.I)
+        content = re.sub("s.preserve_paths *= *((\'|\")(\D*?)(\'|\") *,* *)+", "", content, 1, flags=re.I)
+        content = re.sub("if spec\[:resource[s]?\]\n *ss.resources = spec\[:resource[s]?\]\n *end", "", content, 0,
+                         flags=re.I)
+        content = re.sub("if spec\[:resource_bundles?\]\n *ss.resource_bundles? = spec\[:resource_bundles?\]\n *end",
+                         "", content, 0, flags=re.I)
         return content
 
     def podspecForPush(self, podName, version, url=""):
